"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileStoreRepository = void 0;
const node_zlib_1 = __importDefault(require("node:zlib"));
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const node_uuid_1 = __importDefault(require("node-uuid"));
const FileSystemAdapter_1 = require("../../driven/FileSystemAdapter");
const constants_1 = require("../../shared/constants");
const ArtifactoryAdapter_1 = require("../../driven/ArtifactoryAdapter");
const THOUSAND = 1000;
class FileStoreRepository {
    constructor(stepId) {
        this.stepId = stepId;
        this.logger = logger_1.LoggerFactory.getLogger(`FileStoreRepository:${this.stepId}`);
        this.fileAdapter = new FileSystemAdapter_1.FileSystemAdapter(stepId);
        this.rtAdapter = new ArtifactoryAdapter_1.ArtifactoryAdapter();
    }
    async cleanTempFolder() {
        try {
            await this.fileAdapter.clearTempFolder();
        }
        catch (error) {
            this.logger.warn(`Cannot clear temp folder. error: ${(0, node_util_1.inspect)(error)}`);
        }
    }
    async createLogFile(stepletId) {
        return this.fileAdapter.createFile(stepletId);
    }
    async appendStepConsoles(filePath, stepConsoleLogs) {
        try {
            await this.fileAdapter.writeLogsToFile(filePath, stepConsoleLogs);
        }
        catch (error) {
            this.logger.warn(`Cannot add step logs to file. Error:${(0, node_util_1.inspect)(error)}`);
        }
    }
    async appendSetupConsoles(filePath, stepletSetupAndCleanUpLogs) {
        try {
            const setupLogs = stepletSetupAndCleanUpLogs.get(constants_1.StepletLogsStage.SETUP) ?? [];
            await this.fileAdapter.writeLogsToFile(filePath, setupLogs);
        }
        catch (error) {
            this.logger.warn(`Cannot add setup logs to file. Error:${(0, node_util_1.inspect)(error)}`);
        }
    }
    async appendCleanupConsoles(filePath, stepletSetupAndCleanUpLogs) {
        try {
            const cleanupLogs = stepletSetupAndCleanUpLogs.get(constants_1.StepletLogsStage.CLEANUP) ?? [];
            await this.fileAdapter.writeLogsToFile(filePath, cleanupLogs);
        }
        catch (error) {
            this.logger.warn(`Cannot add cleanup logs to file. Error:${(0, node_util_1.inspect)(error)}`);
        }
    }
    async deleteFile(filePath) {
        return this.fileAdapter.deleteFile(filePath);
    }
    async appendExecutionLogs(filePath, getUrl, token, stepletId) {
        try {
            const readStream = await this.rtAdapter.readLogFile(getUrl, token);
            const decompressor = node_zlib_1.default.createGunzip();
            const decompressedStream = readStream.pipe(decompressor);
            await this.fileAdapter.writeStreamToFile(filePath, decompressedStream);
        }
        catch (error) {
            this.logger.warn(`Cannot write steplet execution logs because of the error: ${(0, node_util_1.inspect)(error)}`);
            await this.appendFallbackExecutionLogMessage(filePath, stepletId);
        }
    }
    async uploadToArtifactory(filePath, putUrl, token) {
        try {
            const readStream = this.fileAdapter.getReadStream(filePath);
            const compressor = node_zlib_1.default.createGzip();
            const compressedStream = readStream.pipe(compressor);
            await this.rtAdapter.upload(compressedStream, putUrl, token);
        }
        catch (error) {
            this.logger.warn(`Cannot upload to artifactory. Error:${(0, node_util_1.inspect)(error)}`);
        }
    }
    async appendFallbackExecutionLogMessage(filePath, stepletId) {
        const grpConsoleId = node_uuid_1.default.v4();
        const cmdConsoleId = node_uuid_1.default.v4();
        const fallbackMessage = [
            {
                stepletId: stepletId,
                consoleId: grpConsoleId,
                parentConsoleId: 'root',
                type: 'grp',
                message: 'Executing Step',
                timestamp: Date.now() * THOUSAND,
                stage: 'execution',
                isShown: true,
                timestampEndedAt: Date.now() * THOUSAND
            },
            {
                stepletId: stepletId,
                consoleId: cmdConsoleId,
                parentConsoleId: grpConsoleId,
                type: 'cmd',
                message: 'Unable to find execution logs',
                timestamp: Date.now() * THOUSAND,
                stage: 'execution',
                isShown: true,
                timestampEndedAt: Date.now() * THOUSAND
            }
        ];
        return this.fileAdapter.writeLogsToFile(filePath, fallbackMessage);
    }
}
exports.FileStoreRepository = FileStoreRepository;
//# sourceMappingURL=FileStoreRepository.js.map